diff --git a/.env.development b/.env.development
index 015f8308..5c9bc531 100644
--- a/.env.development
+++ b/.env.development
@@ -27,4 +27,4 @@ VITE_APP_BASE_API_Url = 'https://aitstest.jlbank.com.cn:7001'
VITE_APP_BASE_H5_API_Url = 'http://25.18.122.65:7001'
#VITE_APP_BASE_H5_API_Url_TRAAPP = 'http://25.64.16.130:9601'
-VITE_APP_BASE_H5_API_Url_TRASTUDY = 'http://25.64.16.130:9602'
+#VITE_APP_BASE_H5_API_Url_TRASTUDY = 'http://25.64.16.138:9602'
diff --git a/src/pages/examination/result.vue b/src/pages/examination/result.vue
index 234a4913..0c9a0bf9 100644
--- a/src/pages/examination/result.vue
+++ b/src/pages/examination/result.vue
@@ -3,7 +3,7 @@
考试结算
-
+
@@ -116,25 +116,8 @@
你的等待会有更精确的结果,要耐心哦~
-
-
-
-
+
@@ -145,6 +128,8 @@
import { onLoad } from '@dcloudio/uni-app';
import { ref, reactive, computed, onMounted, nextTick, getCurrentInstance } from 'vue';
import { queryPaperExamScore } from '@/api/examination.js';
+ import Subject from '@/components/examination/subject.vue';
+ import common from '@/common/common';
const pass_status = ref(0);
const sheet_swiper_index = ref(0);
const result = reactive({
diff --git a/src/pages/learningTasks/components/list-item.vue b/src/pages/learningTasks/components/list-item.vue
index b5b49f9e..f1d07fc0 100644
--- a/src/pages/learningTasks/components/list-item.vue
+++ b/src/pages/learningTasks/components/list-item.vue
@@ -4,7 +4,7 @@
- 进行中
+ 未完成
已完成
@@ -147,7 +147,7 @@
}
.blod_color {
- color: #0066ff;
+ color: #333333;
}
}
@@ -223,6 +223,7 @@
flex-wrap: nowrap;
height: 23rpx;
overflow: hidden;
+
}
.people_progress_div {
diff --git a/src/pages/learningTasks/details.vue b/src/pages/learningTasks/details.vue
index 587bab39..0675ef69 100644
--- a/src/pages/learningTasks/details.vue
+++ b/src/pages/learningTasks/details.vue
@@ -69,32 +69,38 @@
- 进行中
- 已完成
- 未解锁
+ 进行中
+ 已完成
+ 未解锁
- {{item.crsName}}
+ {{ item.crsName }}
-
+
暂无通过条件,可自动解锁
-
+
完成练习
-
-
- 通过考试
-
+
+
+ 通过考试
+
+
@@ -102,7 +108,7 @@
diff --git a/certificate/ios/jiaixuedev.mobileprovision b/certificate/ios/jiaixuedev.mobileprovision
index e3cc651a..f72974ab 100644
Binary files a/certificate/ios/jiaixuedev.mobileprovision and b/certificate/ios/jiaixuedev.mobileprovision differ
diff --git a/src/components/examination/subject.vue b/src/components/examination/subject.vue
index 7dc8587f..68ee2a94 100644
--- a/src/components/examination/subject.vue
+++ b/src/components/examination/subject.vue
@@ -2,7 +2,7 @@
{{ subject_type_text }}
- {{ item.tgtGrade }}分
+ {{ item.tgtGrade }}分
@@ -14,9 +14,9 @@
>
-
+
展开
-
+
@@ -52,17 +52,15 @@
确定
-
+
正确答案:{{ correctResultLabel.join('') }}
你的答案:
- {{ myResultLabel.join('') }}
+ {{ myResultLabel.join('') }}
-
- 题目解析:{{subject_data?.analyContent}}
-
+ 题目解析:{{ subject_data?.analyContent }}
@@ -77,7 +75,7 @@
backgroundColor: '#0066FF',
border: '1rpx solid rgb(12, 123, 245)'
};
-
+
const emit = defineEmits(['subject_click']);
const props = defineProps({
modelValue: {
@@ -92,8 +90,8 @@
type: String,
required: true,
validator: (value) => {
- // 考试: examination 练习: practice 错题本: mistake 学习: study
- return ['examination', 'practice', 'mistake', 'study'].includes(value);
+ // 考试: examination 练习: practice 错题本: mistake 学习: study 考试结算页 settlement
+ return ['examination', 'practice', 'mistake', 'study', 'settlement'].includes(value);
}
},
// 是否预览模式
@@ -105,13 +103,13 @@
clearResult: {
type: Boolean,
default: true
- },
+ }
});
const modelValue = computed({
get: () => props.modelValue,
set: (val) => emit('update:modelValue', val)
});
- let answerText = props.item?.my_answer
+ let answerText = props.item?.my_answer;
const item_answer = ref(typeof answerText === 'string' ? answerText.split(',') : []);
const feedback_click = () => {
emit('subject_click', 'feedback', props.item);
@@ -130,12 +128,18 @@
const anserResultArray = props.item.anserResult.split(',');
return subject_data.itemVos.filter((res) => anserResultArray.includes(res.itemId)).map((res) => res.itemNo);
});
+ // 判断选项是否完全正确
+ const right_or_wrong_class = computed(
+ () =>
+ correctResultLabel.value.length === myResultLabel.value.length &&
+ myResultLabel.value.every((res) => correctResultLabel.value.includes(res))
+ );
const subject_data = reactive({
qnsId: props.item.qnsId,
qnsContent: props.item.qnsContent,
qnsTyp: props.item.qnsTyp,
analyContent: props.item.analyContent,
- itemVos: (props.item.itemVos??[]).map((res) => ({
+ itemVos: (props.item.itemVos ?? []).map((res) => ({
...res,
correctFlag: props.clearResult ? '' : res.correctFlag
}))
@@ -212,18 +216,20 @@
justify-content: space-between;
align-items: center;
margin: 32rpx 0 28rpx 0;
-
+
.success_answer {
}
-
+
.your_answer {
- }
-
- .red_color {
- color: #f5212d;
+ .success {
+ color: #15b859;
+ }
+ .error {
+ color: #f5212d;
+ }
}
}
-
+
.analysis_note {
font-family: PingFangSC;
font-weight: 500;
@@ -272,11 +278,13 @@
.right_text {
font-family: PingFangSC;
- font-weight: 600;
+ font-weight: 400;
font-size: 28rpx;
- color: #333;
+ color: #333333;
+ line-height: 40px;
text-align: left;
font-style: normal;
+
}
}
}